Contributions
=============

.. include:: includes/zope2_notice.rst

Contributors to this book include Amos Latteier, Michel Pelletier,
Chris McDonough, Evan Simpson, Tom Deprez, Paul Everitt, Bakhtiar
A. Hamid, Geir Baekholt, Thomas Reulbach, Paul Winkler, Peter Sabaini,
Andrew Veitch, Kevin Carlson, Joel Burton, John DeStefano, Tres Seaver,
Hanno Schlichting, and the Zope Community.

Amos and Michel wrote the entirety of the first edition of this
book, and kept the online version of the book current up until Zope
2.5.1.

Tom Deprez provided much-needed editing assistance on the first
book edition.

Evan Simpson edited the chapters related to ZPT for the 2.6
edition.

Paul Everitt contributed to the first few chapters of the first
edition, edited the first few chapters of the second edition for
sanity and contributed some "Maintaining Zope" content for the
2.6 edition.

Bakhtiar Hamid edited the ZEO chapter for the 2.6 edition.

Geir edited and extended the Users and Security chapter for the 2.6
edition.

Paul Winkler with help from Peter Sabaini expertly massaged the
Advanced Scripting chapter into coherency for the 2.6 edition.

Peter Sabaini greatly fleshed out and extended the "Maintaining Zope"
and the "Searching and Categorizing Content" chapter for the 2.6 Edition. 

Andrew Veitch cheerfully performed the thankless task of
editing and extending the Relational Database Connectivity chapter
for the 2.6 edition.

Kevin Carlson masterfully edited and expanded the Advanced DTML
chapter. 

Joel Burton rewrote the ZCatalog chapter late in the 2.6 book's
lifetime.

Dario Lopez-Kästen updated the "Introducing Zope" chapter for the
2.7 edition.

Chris McDonough edited the entirety of the book for the 2.6
edition, entirely rewrote a few chapters and added new material
related to object orientation, using the Zope management interface,
acquisition, installation, services, virtual hosting, sessions, and
DTML name lookup rules.

Jo <jo at winfix dot it> has contributed a number of spelling corrections.

John DeStefano edited chapters of the book in a post-2.7-edition mode.

Tres Seaver moved the text into the Zope Subversion repository, and
helped with the conversion of the text from ``Structured Text``
to ``ReStructured Text``.

Hanno Schlichting did the remainder of the ``ReStructured Text`` conversion,
completed the integration with Sphinx and rewrote many chapters for Zope 2.12.

Anyone who added a comment to the online BackTalk edition of the
first online edition of this book contributed greatly.  Thank you!
